#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_POSMAX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_POSMAX_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/posmax.hpp>

#endif
